==> maven-pmd-plugin-3.18.0-source-release.zip: maven-pmd-plugin-3.18.0/src/test/java/org/apache/maven/plugins/pmd/exec/ExecutorTest.java <==
package org.apache.maven.plugins.pmd.exec;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLClassLoader;

import org.apache.commons.lang3.SystemUtils;

import junit.framework.Assert;
import junit.framework.TestCase;

public class ExecutorTest extends TestCase
{
    public void testBuildClasspath() throws MalformedURLException {
        String basename = "home/test/dir with space/mylib.jar";
        String pathname = new File("/", basename).getPath();
        if ( SystemUtils.IS_OS_WINDOWS )
        {
            pathname = new File( File.listRoots()[0], basename ).getPath();
        }
        URL[] urls = new URL[] { new File(pathname).toURI().toURL() };
        URLClassLoader mockedClassLoader = new URLClassLoader( urls );

        StringBuilder classpath = new StringBuilder();
        Executor.buildClasspath(classpath, mockedClassLoader);
        Assert.assertEquals( pathname + File.pathSeparator, classpath.toString() );
    }
}

==> maven-pmd-plugin-3.22.0-source-release.zip: maven-pmd-plugin-3.22.0/src/test/java/org/apache/maven/plugins/pmd/exec/ExecutorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.pmd.exec;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLClassLoader;

import junit.framework.Assert;
import junit.framework.TestCase;
import org.apache.commons.lang3.SystemUtils;

public class ExecutorTest extends TestCase {
    public void testBuildClasspath() throws MalformedURLException {
        String basename = "home/test/dir with space/mylib.jar";
        String pathname = new File("/", basename).getPath();
        if (SystemUtils.IS_OS_WINDOWS) {
            pathname = new File(File.listRoots()[0], basename).getPath();
        }
        URL[] urls = new URL[] {new File(pathname).toURI().toURL()};
        URLClassLoader mockedClassLoader = new URLClassLoader(urls);

        StringBuilder classpath = new StringBuilder();
        Executor.buildClasspath(classpath, mockedClassLoader);
        Assert.assertEquals(pathname + File.pathSeparator, classpath.toString());
    }
}
